@@ -6,6 +6,7 @@ from pipeline.storage import storage
 
 __all__ = ["glob", "iglob"]
 
+
 def glob(pathname):
     """Return a list of paths matching a pathname pattern.
 
@@ -27,7 +28,7 @@ def iglob(pathname):
         return
     dirname, basename = os.path.split(pathname)
     if not dirname:
-        for name in glob1(storage.location, basename):
+        for name in glob1(dirname, basename):
             yield name
         return
     if has_magic(dirname):
@@ -46,9 +47,8 @@ def iglob(pathname):
 # They return a list of basenames. `glob1` accepts a pattern while `glob0`
 # takes a literal basename (so it only has to check for its existence).
 
+
 def glob1(dirname, pattern):
-    if not dirname:
-        dirname = storage.location
     try:
         directories, files = storage.listdir(dirname)
         names = directories + files
@@ -58,6 +58,7 @@ def glob1(dirname, pattern):
         names = filter(lambda x: x[0] != '.', names)
     return fnmatch.filter(names, pattern)
 
+
 def glob0(dirname, basename):
     if storage.exists(os.path.join(dirname, basename)):
         return [basename]
@@ -66,5 +67,6 @@ def glob0(dirname, basename):
 
 magic_check = re.compile('[*?[]')
 
+
 def has_magic(s):
     return magic_check.search(s) is not None
